@@ -1,6 +1,7 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from PyQt4.QtCore import QCoreApplication
+                           #!/usr/bin/env python
+# -*- coding: utf-8 -*-
+from PyQt4.QtCore import QCoreApplication, Qt
 from PyQt4.QtGui import QApplication
 from soundstub import MainWindow
 
@@ -10,7 +11,6 @@ if __name__ == "__main__":
     app = QApplication(sys.argv)
     QCoreApplication.flush()
     ui = MainWindow()
-    #ui.setAttribute(WA_Maemo5AutoOrientation, True);
+    ui.setAttribute(Qt.WA_Maemo5StackedWindow)
     ui.showFullScreen()
-    #ui.show()
     sys.exit(app.exec_())
